package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````W"````````!``````````.BA````
M````!0```$``.``*`$``&P`:``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````'6@`````````````````````````````&8````````````````````!
M``````````$````%````````````````````````````````````A)L`````
M``"$FP`````````0`````````0````8```"8FP```````)BK````````F*L`
M``````"X!````````.`$`````````!`````````"````!@```+";````````
ML*L```````"PJP```````!`"````````$`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````,`$````````P`0````````0`
M````````4.5T9`0```#XD@```````/B2````````^)(```````#L````````
M`.P`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````F)L```````"8
MJP```````)BK````````:`0```````!H!`````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`!6J65DASE$PK2['F)N@;'^,/[N2!````&````!^&O[*1D1/`'LB='EP92(Z
M(F1E8B(L(F]S(CHB=6)U;G1U(BPB;F%M92(Z(F=L:6)C(BPB=F5R<VEO;B(Z
M(C(N-#`M,75B=6YT=3,B+")A<F-H:71E8W1U<F4B.B)R:7-C=C8T(GT```0`
M``!L````?AK^RD9$3P![(G1Y<&4B.B)D96(B+")O<R(Z(G5B=6YT=2(L(FYA
M;64B.B)L:6)P87(M<&%C:V5R+7!E<FPB+")V97)S:6]N(CHB,2XP-C,M,6)U
M:6QD,2(L(F%R8VAI=&5C='5R92(Z(G)I<V-V-C0B?0`$````$`````$```!'
M3E4```````0````/```````````````1````1P````0````(````()`0`05`
M!,0H`@$$@(8$A(*)``()(`0(B(`00;H``H@`````1P```$H```!-````3@``
M`%8```!7````60```%L```!<````70```%\```!A````8@```&0`````````
M`````&[%WQ_.WD<M:W^:?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"
M^M>'PN4_++KCDGSZH6Q@F4_#FVL)0]9FK\QF&7X*AT)%U>R)!W#3<U"?V#-B
MV^T^S])L%8PES`PZEPO_8?)A?ZF<F^"G`@IK&IY0H^#[20``````````````
M`````````````````````````````P`-`#`?``````````````````#G`@``
M$0````````````````````````#5````$@````````````````````````#%
M`0``$@````````````````````````##`@``$@``````````````````````
M``"'````$@````````````````````````!.`0``$@``````````````````
M``````"6`@``$@````````````````````````#,`0``$@``````````````
M``````````!E`0``$@````````````````````````"5`0``$@``````````
M``````````````#K````$@````````````````````````"R`@``$@``````
M``````````````````#-`@``$0````````````````````````"=`@``$@``
M``````````````````````"(`0``$@`````````````````````````<`0``
M$@`````````````````````````,`0``$@````````````````````````#^
M````$@````````````````````````#Q`0``$@``````````````````````
M``#3`0``$@````````````````````````"^`0``$@``````````````````
M``````#5`@``$@`````````````````````````!````(```````````````
M```````````'`@``$@````````````````````````!L`0``$@``````````
M```````````````=````(`````````````````````````!#`@``$@``````
M``````````````````"F`0``$@`````````````````````````W````$@``
M``````````````````````"D`@``$@````````````````````````#+`@``
M$0````````````````````````!4````%@``````````````````````````
M`@``$@`````````````````````````^`0``$@``````````````````````
M``"K`@``$@`````````````````````````F`@``$@``````````````````
M``````!G````$@````````````````````````"``@``$@``````````````
M``````````#$````$@````````````````````````!X````$@``````````
M``````````````"-`0``$@````````````````````````"H````$@``````
M``````````````````#:````$@````````````````````````!Y`@``$@``
M``````````````````````#K`0``$@`````````````````````````P`0``
M$@````````````````````````"?`0``$@````````````````````````!C
M`@``$@````````````````````````!<`@``$0``````````````````````
M``#?````$@````````````````````````"V`0``$@``````````````````
M``````!"`@``$@````````````````````````!J`@``(@``````````````
M``````````"3````$@`````````````````````````0`@``$@``````````
M``````````````#9`0``$@````````````````````````"'`@``$@``````
M``````````````````!9`0``$@`````````````````````````T`@``$@``
M``````````````````````"O`P``$@````````````````````````"W````
M$0`````````````````````````8`@``$@`````````````````````````E
M`0``$@````````````````````````!%````$@``````````````````````
M``!*`@``$@````````````````````````".`@``$@``````````````````
M``````#>`0``$@````````````````````````!W`0``$@``````````````
M``````````"O`0``$@````````````````````````"X`P``$@`-`!@X````
M````M@````````!*!```$@`-`"@Q````````+@4```````!7`@``$@`-`#`?
M````````J@$````````O`P``$@`-``(H````````$`````````!-`P``$@`-
M`%8V````````P@$```````!P!```$@`-`!(H````````M`$````````P!```
M$``7`%"P``````````````````!``P``$@`-`,8I````````*`````````!C
M`P``$@`-`(8N````````6@````````#0`P``$0`.`(!1````````!```````
M```-!```$@`-`*I.`````````@$````````H!```$@`-`!(G````````-@``
M``````!%!```$``7`'BP``````````````````!>!```$@`-`%8P````````
MT@````````"'!```$@`-`.`N````````5`````````#?`P``$``6``"P````
M``````````````"'`P``$@`-`.XI````````\@````````#[`P``$`#Q_P"X
M``````````````````!7!```$``6`%"P``````````````````!]!```$0`6
M`$BP````````"``````````8!```$``6`%"P``````````````````#E`P``
M$@`-`-P@````````(@````````#L`P``$``6``"P```````````````````\
M!```$@`-`$Y.````````7`````````#A`P``(``6``"P````````````````
M``#$`P``$``7`'BP``````````````````"=`P``$@`-`#HP````````'```
M``````!Q`P``$@`-`$@G````````N@````````"3`P``$@`-`*Q/````````
MN@$```````"/!```$@`-`.`J````````I@,`````````7TE435]D97)E9VES
M=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`
M4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!0
M97)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U
M;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,
M;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO
M8P!?7W-T86-K7V-H:U]F86EL`&5X:70`;'-E96LV-`!R96%D9&ER-C0`<W1R
M9'5P`&-L;W-E9&ER`&]P96XV-`!S=')R8VAR`'5N;&EN:P!S=')T;VL`<W1R
M;&5N`')M9&ER`')E860`7U]M96UC<'E?8VAK`&UK9&ER`%]?=F9P<FEN=&9?
M8VAK`&=E='!I9`!R96%D;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C:&L`7U]M
M96UM;W9E7V-H:P!?7V9P<FEN=&9?8VAK`&QS=&%T-C0`7U]L:6)C7W-T87)T
M7VUA:6X`<W1D97)R`&UE;6-H<@!?7V-X85]F:6YA;&EZ90!S=')C:'(`;65M
M8VUP`&UE;7-E=`!O<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T<F-M
M<`!?7V5R<FYO7VQO8V%T:6]N`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T
M97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\N-2XT,`!L
M:6)C+G-O+C8`;&0M;&EN=7@M<FES8W8V-"UL<#8T9"YS;RXQ`'!A<E]C=7)R
M96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN=&5R;F%L<U]005)?0D]/5`!P
M87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M
M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L
M96%N=7``7U]"4U-?14Y$7U\`7TE/7W-T9&EN7W5S960`7U]D871A7W-T87)T
M`%]?1$%405]"14=)3E]?`%]?9VQO8F%L7W!O:6YT97(D`'-H85]U<&1A=&4`
M7U]31$%405]"14=)3E]?`'AS7VEN:70`7U]B<W-?<W1A<G0`<VAA7VEN:70`
M7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P871H`'!A
M<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI=%]E;G8`1TQ)
M0D-?,BXS-`!'3$E"0U\R+C,S`$=,24)#7S(N,C<````````"``$``P`#``$`
M`0`#``,``P`#``$``P`#``,``P`!``$``0`#``,``P`#``$``P`!``$`!``#
M``$``P`#``$``P`!``,``P`!``,``0`!``,``0`#``,``P`!``,``P`#``$`
M`P`$``,``0`#``,``P`!``,``P`!``,``0`!``4``P`#``,``P`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``,`"0,``!````!`````M)&6!@``!0"<!```$````+.1E@8`
M``0`IP0``!````"'D98&```#`+($`````````0`!`!,#```0`````````(>1
ME@8```(`L@0```````"8JP````````,`````````_B````````"@JP``````
M``,`````````OB$```````"HJP````````,`````````@"$```````#XKP``
M``````,`````````,!\`````````L`````````,``````````+`````````8
ML`````````,`````````X%(````````@L`````````,`````````2%4`````
M```HL`````````,`````````4%4````````PL`````````,`````````6%4`
M```````XL`````````,`````````8%4```````!(L`````````,`````````
M:%4```````"@KP````````(````"``````````````"HKP````````(````,
M``````````````"PKP````````(````.``````````````"XKP````````(`
M```8``````````````#`KP````````(````;``````````````#(KP``````
M``L````A``````````````#0KP````````(````C``````````````#8KP``
M``````(````F``````````````#@KP````````(````R``````````````#H
MKP````````(````V``````````````#PKP````````(````^````````````
M``#0K0````````4````#``````````````#8K0````````4````$````````
M``````#@K0````````4````%``````````````#HK0````````4````&````
M``````````#PK0````````4````'``````````````#XK0````````4````(
M````````````````K@````````4````)```````````````(K@````````4`
M```*```````````````0K@````````4````+```````````````8K@``````
M``4````-```````````````@K@````````4````/```````````````HK@``
M``````4````0```````````````PK@````````4````1```````````````X
MK@````````4````2``````````````!`K@````````4````3````````````
M``!(K@````````4````4``````````````!0K@````````4````5````````
M``````!8K@````````4````6``````````````!@K@````````4````7````
M``````````!HK@````````4````9``````````````!PK@````````4````:
M``````````````!XK@````````4````<``````````````"`K@````````4`
M```=``````````````"(K@````````4````>``````````````"0K@``````
M``4````?``````````````"8K@````````4````B``````````````"@K@``
M``````4````D``````````````"HK@````````4````E``````````````"P
MK@````````4````G``````````````"XK@````````4````H````````````
M``#`K@````````4````I``````````````#(K@````````4````J````````
M``````#0K@````````4````K``````````````#8K@````````4````L````
M``````````#@K@````````4````M``````````````#HK@````````4````N
M``````````````#PK@````````4````O``````````````#XK@````````4`
M```P````````````````KP````````4````Q```````````````(KP``````
M``4````S```````````````0KP````````4````T```````````````8KP``
M``````4````U```````````````@KP````````4````W```````````````H
MKP````````4````X```````````````PKP````````4````Y````````````
M```XKP````````4````Z``````````````!`KP````````4````[````````
M``````!(KP````````4````\``````````````!0KP````````4````]````
M``````````!8KP````````4````_``````````````!@KP````````4```!`
M``````````````!HKP````````4```!!``````````````!PKP````````4`
M``!"``````````````!XKP````````4```!#``````````````"`KP``````
M``4```!$``````````````"(KP````````4```!%``````````````"0KP``
M``````4```!&``````````````"7DP``,P/#00.^`R03`T/]DX(#)!-3$P"#
MLH(`9P`.`!>>```#/@XC9P,.`!,````7G@```SZ.(F<##@`3````%YX```,^
M#B)G`PX`$P```!>>```#/HXA9P,.`!,````7G@```SX.(6<##@`3````%YX`
M``,^CB!G`PX`$P```!>>```#/@X@9P,.`!,````7G@```SZ.'V<##@`3````
M%YX```,^#A]G`PX`$P```!>>```#/HX>9P,.`!,````7G@```SX.'F<##@`3
M````%YX```,^CAUG`PX`$P```!>>```#/@X=9P,.`!,````7G@```SZ.'&<#
M#@`3````%YX```,^#AQG`PX`$P```!>>```#/HX;9P,.`!,````7G@```SX.
M&V<##@`3````%YX```,^CAIG`PX`$P```!>>```#/@X:9P,.`!,````7G@``
M`SZ.&6<##@`3````%YX```,^#AEG`PX`$P```!>>```#/HX89P,.`!,````7
MG@```SX.&&<##@`3````%YX```,^CA=G`PX`$P```!>>```#/@X79P,.`!,`
M```7G@```SZ.%F<##@`3````%YX```,^#A9G`PX`$P```!>>```#/HX59P,.
M`!,````7G@```SX.%6<##@`3````%YX```,^CA1G`PX`$P```!>>```#/@X4
M9P,.`!,````7G@```SZ.$V<##@`3````%YX```,^#A-G`PX`$P```!>>```#
M/HX29P,.`!,````7G@```SX.$F<##@`3````%YX```,^CA%G`PX`$P```!>>
M```#/@X19P,.`!,````7G@```SZ.$&<##@`3````%YX```,^#A!G`PX`$P``
M`!>>```#/HX/9P,.`!,````7G@```SX.#V<##@`3````%YX```,^C@YG`PX`
M$P```!>>```#/@X.9P,.`!,````7G@```SZ.#6<##@`3````%YX```,^#@UG
M`PX`$P```!>>```#/HX,9P,.`!,````7G@```SX.#&<##@`3````%YX```,^
MC@MG`PX`$P```!>>```#/@X+9P,.`!,````7G@```SZ."F<##@`3````%YX`
M``,^#@IG`PX`$P```!>>```#/HX)9P,.`!,````7G@```SX."6<##@`3````
M%YX```,^C@AG`PX`$P```!>>```#/@X(9P,.`!,````7G@```SZ.!V<##@`3
M````%YX```,^#@=G`PX`$P```!UQANRBZ,K@@!"FY$[\4OBJAQ>9```#.>D%
M(SBT^B,TQ/J3!03[$P:$^A,%Q/LC+O3Z@S<)`",T]/R!1^_P7_87E@```S:&
M`[*%%Y4```,UY07O,$`>EY<``(.WIP:#QP<`8X0'#I>7``"#MR<#EY0``).$
MI`N2EYAC@RG$^X-'ITL;A4D`#@63YS<`(PWW2N_P'^R#-03[%Y8```,V!@B#
M)\3[`[@%`*J&%S<``!,'9U87-0``$P5E59CNE.0CL`8!B.:0Z@5'C2EC6?<,
MH04;A3<`$4>089,7-P"VEP4GD..A!>,9I_X.!XAL-I<C,`<`3H8!1Y<%``"3
MA<5H[_`_NS7)B&P3"D3\[_!_VJJ)TH47-0``$P7E(N\`0!@EP8AL[_#_M._P
MO\L#-X3\@S<)`+F/`4>EZ^9@1F2F9`9I0GI.A>)Y)6&"@._P?\:7E```DX2D
M_8CL(<7O\'_/EY<``(.WI_.%9C.'1P`88S:7(PL'D@FWB&SO\)^[8;>(:`'%
M[Q!@=FF_TH47-0``$P7E$^\`P!"(Z$'5Y;<11ZFW!47O\/^W[_"_XP``[P`@
M`JJ'%Y4```,U9?&"93``$W$!_X%&`4<*B._PG]X"D)>1``"3@2%P@H```$$1
M(N`&Y``(%Y4``!,%Y?.7EP``DX=G\V.+IP"7EP``@[<GZ8G'`F2B8$$!@H>B
M8`)D00&"@!>5```3!07QEY4``).%A?")C4$1D]<U0/V1(N`&Y``(OI6%A9')
MEY<``(.WI^6)QP)DHF!!`8*'HF`"9$$!@H"7EP``@\<'[97K01$BX`;D``B7
MEP``@[=GY9''%Y4```,U1>:"E^_P7_:B8`)DA4<7EP``(P#WZD$!@H""@$$1
M(N`&Y``(`F2B8$$!E;]=<:+@AN0F_%[D@`B7EP``@[=GW8.[!P!CA`L(3O12
M\%;L@T<%`"J*KHJJB1,'T`.UQV.&YP"#QQD`A0G]^[N)24&#M`L`N<Q*^%KH
M7HD3"]`#3H;2A2:%[_"_F;.'-`$)Y8/'!P!C@F<#@S2)`"$)[?!">:)Y`GKB
M:D)KIF`&9*)K)H7B=&%A@H`S"7E!$UDY0(4)(Z`J`<Z4X;^!256W@43IOZ)Y
M`GKB:LF_<7$B\2;M2ND`&0;U%YD```,YJ=&3!83U@S<)`",\]/R!1ZJ$[_`_
MN17A@R>$]KUF$6?UCV.%YP`I9V.:YP`FA8E%[_!?F!,U%0`1H`%%`S>$_8,W
M"0"YCP%'F>>J<`ITZF1*:4UA@H#O\/_"57&BX4[UAN6`"9>9``"#N0G+@[<)
M`",\]/J!1QG%)OV#1P4`JH29[^IT`S>$^X.W"0"YCP%'8Y$'#JY@#F2J>6EA
M@H!*^>_P7[PJB6,,!0Q2\4J%[_!_CEG-@T8U`1,*-0&;AB;]&X8&`)GB`T8:
M`&W2`T<U`1L')_V;!@<``>N#1QH`FX<G_9N&!P"]S_'2)H56[>_P?XBJBE*%
M[_#_A[N*J@")*E:%[_`_B-*'5H8FAY<V``"3A@;?B44JBN_PW["3!83S4H7O
M\#^4_5=C"?4`@R>$]+UF$6?UCV.*YP)2A>_PGXY2A>_P/YY*A>IJ[_"_A#WQ
M2H7O\#^2)H7O\-^+ZG1*>0IZ#;>#1BH`0;=2A>_P_^[!OR;]2OE2\5;M[_"_
ML.IT2GD)MUEQHO"F[,KHSN2&]-+@5OQ>]&+P@!B7F0``@[FIMP/'!0"#MPD`
M(SST^(%'DP?0`ZZ$*HEC%/<`DX05`":%[_`O^ZJ*DP5$^4J%[_!?URJ*:<WO
M\._Y8WE5"X,K1/D7G````SPLM(X+`T<)`,J'DP;0`V,"!Q1C!M<``\<7`(4'
M??N[AR=!`SH,`!.%*@`^E5Z:[_#O]B,PJ@`IQ8,W#``#1PD`$P49`-Z7E&,3
M!M`#(X#F``'KA:@#1P4`!06C@.<`-<.VAX4&XQC'_A,'T`,C@.<`A0<#QP0`
MA02%!Z./Y_YU^P,WA/F#MPD`N8\!1^'KIG`&=.9D1FFF:09JXGJB>P)\96&"
M@(/'!`"%!`4*HP_Z_N';@\<$`(4$!0JC#_K^_?/!M[:'5;=:^&;L:N@7G```
M`SP,IP,]#`"#-PT`K<_JAP%*F&>A!]*&!2IE_XTF$YLV`)>7``"#IR>O%Y<`
M`!,'IZZ-[X5'6H4<P^_P+^FJC#G)DQLZ`-J&ZH5>AN_P#_PC,)P!FP<:`(X'
MOIPCL`P`0GOB;$)M(RI$^>FUVH5JA>_PWXDC,*P`JHP1S9,;.@#1OX%'^;5!
M2P%*8;]:^&;L:NCO\+^30GOB;$)M$;]=<:+@)OQ*^$[T4O!6[(`(AN3]<OUW
MDX>'^Q:1A627F@``@[H*FJJ)+HH3AO3_LP7T`!<U```3!<6W@[<*`",\]/J!
M1^_PK^H;"04`8UL@`;,$E$";!_G_OI0#QX3['>^-[Y>7``"#MT>84H;.A9*7
MB&/O\,_B`S>$^X.W"@"YCP%'J>>%8A:1IF`&9.)T0GFB>0)ZXFIA88*`/HG]
M=Y.'A_NS!/0`)H5*AI,%\`+O\`_W1=F7EP``@[<GD\J&)H:2EXACSH7O\(_O
M=;?O\#^&`1$FY)>4``"#M"21(N@&[``0LX=$`(ACEW8``).&YL`7E@```S;F
MCY<U``"3A66L[_#O_9*40F2(8.)@HF07-P``$P<'Y+J&@4<7%@``$P:F]9<U
M``"3A<6K!6%O\"_FEY<``(.W9XM!$2+@!N0`")*7`F2B8(ACEW8``).&YKH7
ME@```S;FB9<U``"3A66F00%O\,_W'7&&[*+HIN2`$,K@3OQ2^%;T^7(7F@``
M`SI*A!:1@S<*`",\]/J!1^_P#]SY=Y.'A_JS!/0`!68JAP4&)H67-P``DX<G
MI9<V``"3AB:EB47O\(_Q_7>3AP?[,PGT`":%RH4%9N_P3]*;!`4`@4ECP00"
MFXH4`%:%[_`/Q:J)"<DFAM:&RH7.E._P#_,C@`0``S>$^X,W"@"YCP%'B>^)
M8A:1YF!.A49DIF0&:>)Y0GJB>B5A@H#O\"_Q01$BX`;D``@"9*)@00$EOU%Q
MHO&F[<KISN5>]8`9AO72X5;]6OEB\6;M_7+]=Y.'1_$6D9>+``"#NZMVJHFN
MA!<U```3!66;LP7T`(.W"P`C//3X@4?O\'^7*HF3!?`"3H7O\,_5(<$7-0``
M$P7EF<Z%[_#?N4Z%`S>$^8.W"P"YCP%'8YX'$H5B%I&N<`YT[F1.::YI#FKJ
M>DI[JGL*?.IL;6&"@":%[_!OU)<U``"3A:66[_"OKZJ$7=7]=Q.'A_F3AX?Q
M!6NS"O0`DP<$^C.,9T&#QP0`,PKD`,7#8P<)`*:%2H7O\(_%)<TFA>_P#[&3
M!_7_II>JC),&\`)CZ/0`,:@C@`<`_1=CAO0``\<'`.,)U_XFA>_P;ZZJC$Z%
M[_#OK6:5!07C<&7UB44FATZ(ES<``).'QXZ7-@``DX;&C@5F4H7O\(_6UH52
MA>_P#[H!Z8,GC/B]9B%G]8]C@><$ES4``).%18L!1>_P+Z2JA.,+!>Z#QP0`
MM?-C#`D`@T<)`)N')_T;AP<`F>,#1QD`8=N%3)<T``"3A(2%0;>%15*%[_"O
MJ4W]TH47-0``$P6EA>_POZ52A>_P3\-MO>_P[]0!$2+H)N0&[``0DP7P`JJ$
M[_"OQ!G!DP05`$)DXF`FA:)D!6%O\&_`.7$B^$[L!OPF]$KP@`#]<I>)``"#
MN2E:%I&#MPD`(S3T_(%'6<F#1P4`*HG9Q^_P3YX3!A4`A6>JA&/HQPK]=Y.'
MA_PS!_0`RH4ZA>_P;ZZ3A_3_JI>3!O`"8VCU`!&H(X`'`/T78X:G``/'!P#C
M"=?^_7>3AX?\LP3T`":%DP7P`N_P#[L5R6/NI`3]=Y.'A_PS!?0`[_#/M@,W
MA/R#MPD`N8\!1Z'GA6(6D>)P0G2B=`)YXFDA88*``S>$_(.W"0"YCP%'A>>%
M8A:1XG!"=*)T`GGB:1<E```3!<5R(6%O\"^R(P`%`%6W`45]M^_P3\,Y<2+X
M)O1*\$[L@``&_!>)```#.2E+DP1$_(,W"0`C-/3\@4>7B0``@[G)2J:%%R4`
M`!,%)7+O\(_K%<4#)T3\@[<)``X'NI>89YCC9=.8:Z$'F.-M_Z:%%R4``!,%
MA6_O\._H8?V7B0``@[FI1J:%%R4``!,%!6_O\&_G%<4#)T3\@[<)``X'NI>8
M9YCC9=.8:Z$'F.-M_Z:%%R4``!,%96SO\,_D8?V7B0``@[F)0J:%%R4``!,%
M96OO\$_C%<4#)T3\@[<)``X'NI>89YCC9=.8:Z$'F.-M_Z:%%R4``!,%Q6CO
M\*_@8?V7B0``@[EI/J:%%R4``!,%16CO\"_?%<4#)T3\@[<)``X'NI>89YCC
M9=.8:Z$'F.-M_Z:%%R4``!,%I67O\(_<8?V7B0``@[E).J:%%R4``!,%I63O
M\`_;%<4#)T3\@[<)``X'NI>89YCC9=.8:Z$'F.-M_Z:%%R4``!,%!6+O\&_8
M8?V7B0``@[DI-J:%%R4``!,%A6'O\._6%<4#)T3\@[<)``X'NI>89YCC9=.8
M:Z$'F.-M_Z:%%R4``!,%Y5[O\$_48?V7B0``@[D),J:%%R4``!,%Y57O\,_2
M%<4#)T3\@[<)``X'NI>89YCC9=.8:Z$'F.-M_Z:%%R4``!,%15/O\"_08?V7
MB0``@[GI+::%%R4``!,%15KO\*_.%<4#)T3\@[<)``X'NI>89YCC9=.8:Z$'
MF.-M_Z:%%R4``!,%I5?O\`_,8?V7B0``@[G)*::%%R4``!,%)5?O\(_*%<4#
M)T3\@[<)``X'NI>89YCC9=.8:Z$'F.-M_Z:%%R4``!,%A53O\._'8?V7B0``
M@[FI)::%%R4``!,%!53O\&_&%<4#)T3\@[<)``X'NI>89YCC9=.8:Z$'F.-M
M_Z:%%R4``!,%95'O\,_#8?V7B0``@[F)(::%%R4``!,%94;O\$_"%<4#)T3\
M@[<)``X'NI>89YCC9=.8:Z$'F.-M_Z:%%R4``!,%Q4/O\*^_8?VFA1<E```3
M!45-[_"OOJJ%&<47)0``$P5%2N_PS^&FA1<E```3!>5,[_#/O*J%&<47)0``
M$P5E3>_P[]^FA1<E```3!85-[_#ONJJ%%<T7)0``$P4%/>_P#]X#-X3\@S<)
M`+F/`4>IXT)TXG"B=`)YXFF7)0``DX7%3!<E```3!<5`(6%O\"_;IH47)0``
M$P7%2>_P+[:JA6G1%R4``!,%Q4#O\$_95;_O\.^(>7$B\";L`!@&])>$``"#
MM`01DP5$_1<E```3!44^G&`C//3\@4?O\"^R!<6#1P4``46)QY.'!_TS-?``
M`S>$_9Q@N8\!1X'KHG`"=.)D16&"@`%%Y;?O\$^#'7$BZ`;L`!`7@P```S.#
M#RJ.`S4#`!,#A``,Y!#H%.QRAACP%XX```,^S@D<]",X!`,C/!0#FH:)18,W
M#@`C-/3^@4<C,&3^[^"?UA,%\`_OX!_2'7&BZ$[\4OA6](;LIN3*X%KP7NR`
M$,%REXH``(.Z2@46D0E&@[<*`",T]/J!1X%%*HKOX+_BDPGU_Q/7^4-!D[.'
MZ0#"%\&3F8^SB?E`8\P)",%WDX<'^C,)]`!]6YU+`4;.A5*%[^!_WV,&90E!
M9B$&RH52A>_@?^L!)6,'90=C_ZL$816S!*D`8_8D`8&H_11CYB0%(4:7A0``
MDX7%`R:%[^"_V&WUP7>3AP?ZHI<SA?1`3I4#-X3Z@[<*`+F/`4>AX\%B%I'F
M8$9DIF0&:>)Y0GJB>@)[XFLE88*`P7>^F>.?^?9]5?FW%R4``!,%)3'O\+_K
M%R4``!,%92_O\/_J[^"_[4$1!N0BX``([^#_NN_@O^41P0AAHF`"9$$!@H`Y
M<2+X2O!.[(``!OR7B0``@[GI\RJ)DP5$_!<E```3!04M@[<)`",T]/R!1^_P
MSY09Q2;T@T<%`*J$C>>B=`,WA/R#MPD`N8\!1\J%%R4``!,%Y2FMZT)TXG`"
M>>)I(6%O\*^U2H52Z._@/[0JBB:%[^"_LRJ:"0I2A>_@'[0FB$J'ER<``).'
M!Q12AI<F``"3AF84B46JA._@/]P#-X3\@[<)`+F/`4>=XT)T0FKB<`)YXFFF
MA:)T%R4``!,%)2,A86_PCZ\F]%+H[^`?W^_@W]XE<9>'``"3A^?M(NM*XP`3
MSO[2^@;O)N<#N(<#`[\'`8.^AP$#O@<"`[.'`H.X!P,3"<3G%XH```,Z2N2J
MB1<F```3!B8?ER8``).&)@@7)P``$P>G'I<G``"3AZ<>(SP$[<J%%R4``!,%
MQ08#.`H`(SP$^0%((S@$Z",T!.HC..3K(SS4ZR,PQ.TC-&3L(S@4[2,PQ.@C
M--3H(SSDZ",P].KO\$^`$<6#1P4`JH1CF@<BUO;:\M[NXNKOX/^@[^"_RV,(
M!1@#.P4`8P0+&%J%[^"?H),4%0"%!":%[^#?H`-'"P"JBR:,JHH%SY<F``"3
MAD86)H:)15Z%[^#_R`4+XH9C<YP`IH:SAY9`B0=C\]<`MH<#1PL`^125C+Z4
MB0MQ]Q,+!.L7)0``$P4E"2F@`S6+`"$+#<'*A>_@W_:JA&79@T<%`.W7[_"O
M@'71)H7OX)^WJH05X1,+!.B#-`L`B<R#QP0`8X0'#B:%[^!__GGE@S2+`"$+
M[?0FA>_@WY4JBU:%[^!?E3L+JP`;"TM`6H7OX'^5ER<``).')_;6B":'6H87
M*```$PA("Y<F``"3AD8+B46JB^_@'[U>A9,%`!SOX'^N_5=C&/4`[^#?DQQ!
M14=CE^<.DP4$[EZ%[^"_LJJ$`>F#)P3OO6819_6/8XCG"I>'``"#MT?,@[8)
M`(AC7H<7)@``$P;&"HE%[^"_M8%*`S>$^8,W"@"YCP%'8YT'+OI@6F06>_9K
M5FRZ9!II]GE6>E:%MGH=88*`)H7OX)^HJH0A"^,*!?`]MX%$+;>3!(3IB&`9
MR<J%[^"_Y`'%@T<%`)7CB&2A!'WU-47OX)^'-4RJBZJ*XH07*P``$PO+^A,'
M,`65M>_@_Z,JBZ$$<='OX%^$DQ05`(4$-;V#*H3O[^!?@N.6JO2#)P3OYN83
M!P`<D_?W'V.(YP2V;!6_%X<```,W9[^#M@D`"&,7)@``$P8&^EZ'B47OX-^H
M#;_O\-_$`S>$^8,W"@"YCP%'8Y<'(EID^F`::?9Y5GHFA;ID'6%OX#^<6H7O
MX,_]RH6JBA<E```3!47_[^"_V*J%8PL%$`.U"0#O\`^\JHQC!`409H7OX"_Z
M&PP%`(U'8]B'`Q,%S/]FE9<E``"3A67\[^!_C`GMD4=C!/P8FP>\_^:7`\<'
M`),'\`)C"_<6RH47)0``$P5EWN_@W])AP8-'!0#-SQ,'``-CBN<*ER4``).%
M)>87)0``$P4EW._@O_3OX'^&*HA>AUJ&5H67*```DXBH!9<G``"3AR?4ER8`
M`).&)OB)1>_@'YQ]6<5)%RP``!,,C`,5J._@[_(<06.=-P/OX%^"A20JB&+@
MIHA>AUJ&5H67)P``DX<GT)<F``"3AB;UB47OX!^8DP4`'%:%[^!_B>,")?U>
MA>_@WX;6A1<E```3!>7*[^#_ZU:%[_#_K[9L^;N#O`D`Y;UFA8%%[^!_FRJ)
M.='O\#^<JHGC3P7RDP5E_P%&2H7OX-^`$PP$]N*%2H491N_@_XR91V,?]0@#
M)P3VMT=!0Y.'!S#C%_?P`U=,`)%GDX>'5.,0]_"3A>G\`49*A>_@[_R3!(3V
M2H6FA1,&@`+OX/^(DP>``F,>]00FB%J&ER@``).(Z/27)P``DX=GPUZ'ER8`
M`).&1N:)15:%(P@$^._@WXHMOX.YB0#CA0GH3H7OX,_>C4?C_Z?F<15.E9<E
M``"3A>7A[^!O\>,5!>;.C)6U%R4``!,%)>'O\#^*YN;OX-^,UO;:\M[NXNKF
MYN_@_XM=<2;\EX0``(.TY):BX$[T4O"&Y$KX5NR`"+.'1``#N0<`$PI$^Y>)
M``"#N4F2@T<)"]*%%R4``!,%9;T#MPD`(SSD^@%'HPCY"N_@_[(9Q0-'!0"3
M!Q`#8P'W%._P[\*SAT0``[D'`$J%C48%1I<E``"3A<7<[^!/VBJ)!<4<:3.'
M1``(8XQC%R8``!,&IMOOX*_9@S<)`8QCW$43EY<"8TD'$+.'1`"(8XU&!4:7
M)0``DX7%V>_@3]8JB9>*``"3BFJ4%<'2A1<E```3!:6N[^"?JH,W"0$JAHQC
M8<6SAT0`B&/OX&_4LX=$``.Y!P`%1I<E``"3A0762H7OX._'JH47)@``$P:&
MUDJ%[^#OT9*4G&#2A1<E```3!<6HHX@'"N_@?Z4CN*H`JH0IR9,%`!PFA>_@
M;^0;!Q4`A4=C\.<"Q4=C#?4`@[>*`*J&)H:,8Q<E```3!874[^`/Z0,WA/N#
MMPD`N8\!1['KIF`&9.)T0GFB>0)ZXFIA88*``[6*`._P'Y4CN*H`JH1-\1<E
M```3!47.[^!/Y8-'%0#CA0?L;;V#MXH`+H6,8^_@']XEO[.'1`"(8^_@+^#E
MM>_@S^\Y<2+X)O1*\(``!OR7=```@[3$=RJ)DP5$_!<E```3!>6DG&`C-/3\
M@4?OX-^8"<V#1P4`D<L3!P`#8X?G`&,%"0"#1PD`B>\#-X3\G&"YCP%'N>_B
M<$)THG0">2%A@H!*A4[L[_`OEY,%\`*JB>_@K]D9P9,)%0!.A>_@[]411I<E
M``"3A86N[^`/LAG!XFEEOP,WA/R<8+F/`4>9ZT)TXFGB<*)T2H4">2%A;^`_
MHD[L[^!OY!,!`=0C.($J@`4C/!$J(S21*B,P(2LC/#$IEW,``(.S@VN3!H34
MP6Z3"(4#DP^%!X.W`P`C-/3\@4<VB)..#O`W#_\``[8(`*$(00B3508"$Q>&
M`1.3A0&3$H8`DU>&`@(7$UZ&`)-4A@,!DP(3L_+B`;/WUP$34P,",V=7`#-^
MW@&B!<6/,V?'`1M6A@&S]>4!L^=G`%&/S8\C..C^(SSX_N.1^/L#/P3;@SZ$
MVP,W!-P#/H35`S,$UH,XA-8#.`37@S6$UX,_!-B3A`8@$:"RC[!BG&*Z@J$&
ML8^SQ^<!L\?'`1.7%P#]@UV/`A<!D[C^&HYVCT:#EH["B"Z(_H7CF-3\$&$,
M:8,XA0`#.(4!@S:$U`,S!0*35[8!$Q=6`#>.@EH3#IZ978_REK/'!0$3WR@`
M`A>3GN@!FI:S[NX!`9.S]Q<!-I>SQP<!@S8$U1.?#@(37P\"/I<"%[/'Y0$!
MD_&/\I:34K<!DQ]7`*V/PI:S[U\`MI>34B8`_I>3%N8!@S^$U;/F5@"SSMX`
M@A>!D[/^[@#RGY/4MP&NGY.25P"SSNX!L^*2`/Z>EIZ3'^<!@S($U@F#,^?O
M`((>DY\&`KF.D]X.`I/?#P+RDOV.%I^3U+X!DY)>`+/&]@'ZEC/OD@#ZEI.2
MYP$#/X36B8.SY_(`@A:3$@<"/8^!DI/2`@)RGS-WUP%^GY/4M@&3GU8`,T=7
M`'J7,^^?`'J7@S\$UQ.?[@&3WBX`,V_?`1.9!P("%[/'YP$!DQ-9"0*SCL\!
M]8^6GI,?5P"34K<!L\<G`?:7L^Y?`/:7@S*$UY/>)@"3G^8!L^_?`;-&_P&3
M%`\"@A>!DX&0LX["`?F.RIX3GU<`D]*W`:6.]I:S;E\`]I:#,@38DUXG`!,?
MYP$S;]\!,\?O`1.9#P*"%H&2$UD)`K..P@%]CZ:>DY]6`)/2M@$S1R<!=I>S
M[E\`=I>#/X38D]XG`).2YP&SXM(!LT=?`),4#P("%P&3@9"SCL\!]8_*GA,?
M5P"37[<!I8_VE[-N_P'VEP,_!-F3WB8`DY_F`;/OWP&SQO(!$YD"`H(7@9,3
M60D"LP[/`?F.IIX3GU<`D]*W`;/&)@'VEK-N7P#VEH,RA-F37B<`$Q_G`3-O
MWP$SQ^\!DY0/`H(6@9*!D+..P@%]C\J>DY]6`)/2M@$ECW:7L^Y?`':7@S($
MVI/>)P"3G^<!L^_?`;-'_P$3&0\"`A<!DQ-9"0*SCL(!]8^FGA,?5P"34K<!
ML\<G`?:7LVY?`/:7@S*$VI/>)@`3G^8!,V_?`;/&[P&3E`\"@A>!DX&0LX["
M`?F.RIZ3GU<`D]*W`:6.]I:S[E\`]I:#,@3;DUXG`),?YP&S[]\!,T?_`1,9
M#P*"%H&2$UD)`K..P@%]CZ:>$Y]6`)/2M@$S1R<!=I>S;E\`=I>#,H3;D]XG
M`!.?YP$S;]\!L\?O`9.4#P("%P&3@9"SCL(!]8_*GI,?5P"34K<!I8_VE[/N
M7P#VEX,R!-R3WB8`DY_F`;/OWP&S1O\!DQD/`H(7@9.3V0D"LX["`?F.IIX3
MGU<`D]*W`;/&-@'VEK-N7P"#-(3<]I:3$N<!DUXG`+/BT@$SQU\`$Y\&`A.9
M#P(37P\"$UD)`K.&Q`%]C\Z6DQY?`)-?OP$S1R<!-I>SYOX!@S0$W3:7D]\G
M`).6YP&SYO8!L\?2`),>!P*3GP("D]X.`C.'Q`&3WP\"L_?G`4J7DY)>`)/4
MO@&SQ_<!NI<SYY(`NI>#-(3=$Q?O`8(7$U\O`(&3,V?G`1/9MP&3D@8"$Y]7
M`+F.\I23T@(",V\O`;/VU@&FG[/&5@`"'Q-?#P+^EOJ6`SD$WI.?[@$3GP8"
MD]XN`!-?#P*S[M\!DQ1?`'*9DQ\'`A->OP$S1]<!D]\/`C/NQ`%]C\J2,T?W
M`0(>$UX.`A:7DY+G`8F#<I>SXO(`L\=>``,YA-Z3%`<"@9"UC[?VV6Z3AA:Z
MD]FT`1.>5``VF3-N/@&"%\J?@9,"'OZ7$UX.`CZ>DQ_O`1-?+P"S[^\!@S<$
MWQ,9#@(360D",\_R`9-9N0$S3^\`@AX3%UD`D]X.`C-G-P&VEP(?$U\/`O:7
M`A?ZEP&3/I>3GN0!B8"S[IX`@S>$WY,9!P*3V0D",\_?`9/4N0$S3\\!@A(3
MGED`D]("`C-NG@"VEP(?$U\/`I:7`A[ZEQ->#@(^GA,?Z0$362D`,V\O`8,W
M!."3$@X"D]("`K/$[@$3V;(!N8R"'Q.74@"3WP\",V<G`;:7@A2!D/Z7`A>F
MEP&3/I>3G^D!D]DI`+/O/P&#-X3@DQ0'`H&0,TG_`9/9M`$S2<D!@AX3GE0`
MD]X.`C-N/@&VEP(9$UD)`O:7`A[*EQ->#@(^GI.>X@&3TB(`L^Y>`(,W!.$3
M&0X"$UD)`K/"WP&36;D!L\+B``(?$Q=9`!-?#P(S9S<!MI>"$I/2`@+ZEP(7
MEI<!DSZ7$Y_D`8F`,V^?`(,WA.&3$@<"D]("`K/$[@&3V;(!L\3$`8(?$YY2
M`)/?#P(S;CX!MI>"%(&0_I<"'J:7$UX.`CZ>DQ_I`1-9*0"#-P3BL^\O`9,4
M#@*!D#-)_P&3V;0!,TGI`((>$Y=4`)/>#@(S9S<!MI<"&1-9"0+VEP(7RI<!
MDSZ7DY[B`9/2(@"S[EX`@S>$XA,9!P(360D"L\+?`9-9N0&SPL(!`A\3'ED`
M$U\/`C-N/@&VEX(2D]("`OJ7`AZ6EQ->#@(^GA.?Y`&)@#-OGP"#-P3CDQ(.
M`I/2`@*SQ.X!D]FR`;F,@A\3EU(`D]\/`C-G-P&VEX(4@9#^EP(7II<!DSZ7
MDQ_I`1-9*0"S[R\!@S>$XY,4!P*!D#-)_P&3V;0!,TG)`8(>$YY4`)/>#@(S
M;CX!MI<"&1-9"0+VEP(>RI<37@X"/IZ3GN(!D](B`+/N7@"#-P3D$QD.`A-9
M"0*SPM\!DUFY`;/"X@`"'Q,760`37P\",V<W`;:7@A*3T@("^I<"%Y:7`9,^
MEQ.?Y`&)@#-OGP"#-X3DDQ('`I/2`@*SQ.X!D]FR`;/$Q`&"'Q.>4@"3WP\"
M,VX^`;:7@A2!D/Z7`AZFEQ->#@(^GI,?Z0$362D`L^\O`8,W!.63%`X"@9`S
M2?\!D]FT`3-)Z0""'A.75`"3W@X",V<W`;:7`AD360D"]I<"%\J7`9,^EY.>
MX@&3TB(`L^Y>`(,WA.43&0<"$UD)`K/"WP&36;D!L\+"`0(?$QY9`!-?#P(S
M;CX!MI>"$I/2`@+ZEP(>EI<37@X"/IX3G^0!B8`S;Y\`@S<$YI,9#@*3V0D"
ML\+N`9/4N0&SPN(`@A\3EUD`D]\/`D6/MI>"$I/2`@+^EP(7EI<!DSZ7DQ_I
M`1-9*0"S[R\!@S>$YI,4!P*!D+-"_P$3V;0!L\+"`8(>$YY4`)/>#@(S;BX!
MMI>"$I/2`@+VEP(>EI<37@X"LX['`9.2Z0&3V2D`L^(R`8,W!.<3F0X"$UD)
M`C/.7P"36;D!,T[N``(?$Q=9`!-?#P(S9S<!MI<"'A->#@+ZEP(7`9,3G^0!
M\I>)@#-OGP`SCN<``S>$Y[/'X@&SQ]<!DQ0.`H(?@9"3WP\"-I>"%Y.>5`"3
MV;0!@9-^ESZ7DQ_I`;/G/@$362D`L^\O`3Z7@S<$Z#-)_P&3'@<",T[)`8(2
MD]X.`I/2`@*VEP(>$UX.`I:7DY9>`)/2O@&SYE8`$Y?D`?*7B8"#,H3H18^V
ME[?VQB.3%`<"$YX'`I.7)@"3A\?-@9"SYN\`$QD/`A->#@(SC_(`$UD)`K/R
MGP"S]M8!2I^SYE8`$UF^`9,27@#ZEC/O(@'ZE@,Y!.D3G^X!D]XN`#-OWP&3
MD@\",V?G`9.?!@*3WP\"LW:?`+,.^0"3T@(",W?'`9:>$]F_`9.27P!5CW:7
MDQ;N`;/N(@$37BX`L^;&`7:7@SZ$Z9.2!@*3T@(",V[?``(7`9,S>5\`OIXS
M?OX!IIXS;BX!DQ17`!-9MP%VGK/N)`%VG@,Y!.J3GN\!D]\O`+/N_@&3%`X"
ML^;6`0(?@9"S_UX`,P[Y`!-?#P+YCGJ>L^;V`9/9M`&3GU0`$QGG`1-?)P`S
MA\8!LV;I`3/N/P$#/X3J<I>3GP8"D]\/`C/NW@`"%P&3,_G^`3Z?,WZ>`!:?
M,VXN`9,25P`36;<!>IXS[R(!>IX#.03K$Y_D`8F`,V^?`),2#@*SYN8!@AZ3
MT@("LW3_`3,.^0"3W@X"^8YVGL6.D]FR`9.44@`3&><!DUXG`#.'Q@&S9MD!
M,^XT`8,^A.MREY.4!@*!D#-NWP`"%P&3,WF?`+Z>,WY>`/Z>,VXN`9,?5P`3
M6;<!=IZS[B\!=IX#.03LDY[B`9/2(@"S[EX`DQ\.`K/FU@$"'Y/?#P*S\IX`
M,P[Y`!-?#P+YCGJ>L^96`)/9OP&3DE\`$QGG`1-?)P`SA\8!LV;I`3/N,@$#
M/X3L<I>3D@8"D]("`C/NW@`"%P&3,_E>`#Z?,W[^`2:?,VXN`9,45P`36;<!
M>IXS[R0!>IX#.03M$Y_O`9/?+P`S;_\!DQ0.`K/FY@&"'H&0LW]?`#,.^0"3
MW@X"^8YVGK/F]@&3V;0!DY]4`!,9YP&37B<`,X?&`;-FV0$S[C\!@SZ$[7*7
MDY\&`I/?#P(S;M\``A<!DS-Y_P&^GC-^G@"6GC-N+@&3$E<`$UFW`7:>L^XB
M`7:>`SD$[I.>Y`&)@+/NG@"3$@X"L^;6`0(?D]("`K/T_@$S#OD`$U\/`OF.
M>I[%CI/9L@&3E%(`$QGG`1-?)P`SA\8!,^XT`;-FZ0&#-(3N<I<3GP8"$U\/
M`C/NW@`"%P&3,_GN`;Z4,WY>`*:?,VXN`9,45P`36;<!?IZS[R0!?IX#.03O
MDY_B`9/2(@"S[U\`DQ0.`K/F]@&"'H&0L_+O`3,.^0"3W@X"^8YVGK/F5@"3
MV;0!DY)4`!,9YP&37B<`,X?&`3/N,@&S9MD!@S*$[W*7DYX&`I/>#@(S[M\`
M`A<!DS/YWP&^DC-^G@`6GS-N+@&3$E<`$UFW`7J>,^\B`7J>`SD$\!.?Y`&)
M@#-OGP"3$@X"L^;F`8(?D]("`K-TWP$S#OD`D]\/`OF.?IX3V;(!DY]2`,6.
MDQ3G`0F#18_REH,TA/`S[B\!\I:3'P<"D]\/`C-N[P""%H&2,WG_`;Z4,WY>
M`*:>,VXN`9.45@`3V;8!=IZS[B0!=IZ#-`3Q$YGB`9/2(@"3'@X",VY9`#-G
MQP$"'Y/>#@*S@O0`=8^S=/X!$U\/`A:?18^3DEX`D]2^`7J7,^^2``,YA/%Z
MEQ.?Y@&)@K-FWP`"%P&3DY(&`I/2`@(S;]X`DUFW`3Z9DQ17`,J?L^0T`3-Y
M7@`S?]\!,V\O`8(4@9!^GP,Y!/(FGY,?#P*3WP\"DY3N`9/>+@"S[M0!/IF3
ME%\`D]>_`;/FU@'=C`(>L_?F`!->#@*3E@0"L_1>`$J>Q8_REX&2OI:3%.<!
M"8/9C(,YA/(3F08"M[>8,A-9"0(SQYX`B@>3AV<=,T?G`1,>60`37[D!,V[N
M`0(7,X_Y`!:?`9,"'GJ7$UX.`CJ>$Y_O`1/7+P"S;^\`DQ(.`@,_!/.3T@("
M,\?T`9/9L@$UCX(>DY92`#Z?L^8V`9/>#@("%_J>`9."%G:7@9*ZEI,>Z0$3
M5RD`L^[N`!.9!@(#-X3S$UD)`C//WP&36;D!,T_/`8(4$QY9`(&0,VX^`3Z7
M`A\37P\")I<"'GJ7$UX.`CJ>$Y_B`9/2(@`S;U\`DQ0.`@,W!/2!D+/"[@&3
MV;0!L\+2`((?DY94`)/?#P*SYC8!/I>"$I/2`@)^EX(6%I>!DKJ6DQ_I`1-9
M*0"S[R\!DY(&`@,WA/23T@(",TG_`9/9L@$S2<D!@AX3GE(`D]X.`C-N/@$^
MEP(9$UD)`G:7`AY*EQ->#@(ZGI.>Y`&)@+/NG@`3&0X"`S<$]1-9"0*SQ-\!
MDUFY`;6,`A^3%ED`$U\/`K/F-@$^EX(4@9!ZEX(6)I>!DKJ6$Y_B`9/2(@`S
M;U\`DY0&`@,WA/6!D+/"[@&3V;0!L\+"`8(?$YY4`)/?#P(S;CX!/I>"$I/2
M`@)^EP(>%I<37@X".IZ3'^D!$UDI`+/O+P&3$@X"`S<$]I/2`@(S2?\!D]FR
M`3-)V0""'I.64@"3W@X"L^8V`3Z7`AD360D"=I>"%DJ7@9*ZEI.>Y`&)@+/N
MG@`3F08"`S>$]A-9"0*SQ-\!DUFY`;/$Q`$"'Q,>60`37P\",VX^`3Z7@A2!
MD'J7`AXFEQ->#@(ZGA.?X@&3TB(`,V]?`),4#@(#-P3W@9"SPNX!D]FT`;/"
MT@""'Y.65`"3WP\"L^8V`3Z7@A*3T@("?I>"%A:7@9*ZEI,?Z0$362D`L^\O
M`9.2!@(#-X3WD]("`C-)_P&3V;(!,TG)`8(>$YY2`)/>#@(S;CX!/I<"&1-9
M"0)VEP(>2I<37@X".IZ3GN0!B8"S[IX`$QD.`@,W!/@360D"L\3?`9-9N0&U
MC`(?DQ99`!-?#P*SYC8!/I>"%(&0>I>"%B:7@9*ZEA.?X@&3TB(`,V]?`).4
M!@(#-X3X@9"SPNX!D]FT`;/"P@&"'Q.>5`"3WP\",VX^`3Z7@A*3T@("?I<"
M'A:7$UX.`CJ>DQ_I`1-9*0"S[R\!DQ(.`@,W!/F3T@(",TG_`9/9L@$S2=D`
M@AZ3EE(`D]X.`K/F-@$^EP(9$UD)`G:7@A9*EX&2NI:3GN0!B8"S[IX`$YD&
M`@,WA/D360D"L\3?`9-9N0&SQ,0!`A\3'ED`$U\/`C-N/@$^EX(4@9!ZEP(>
M)I<37@X".IX3G^(!D](B`#-O7P"3%`X"`S<$^H&0L\+N`9/9M`&SPM(`@A^3
MEE0`D]\/`K/F-@$^EX(2D]("`GZ7@A86EX&2NI:3'^D!$UDI`+/O+P&3F08"
M`S>$^I/9"0*S0O\!$]FY`;/"P@&"'A.>60"3W@X",VXN`3Z7@A*3T@("=I<"
M'A:7$UX.`K,.QP&3DN0!B8"SXI(`$YD.`@,W!/L360D",\Y?`)-4N0$S3MX`
M`A^3%ED`$U\/`L6./I<"'A->#@)ZEX(6@9(3G^D!<I>3V2D`,V\_`3,.UP"#
M-H3[,\?B`3-'UP&"'Y/?#P*3%`X"OI8"%X&0`9/^EI/9M`&3GU0`NI:3'ND!
M`S<$_!-9*0"S[S\!L^XN`?Z6LT_?`;J7@A*"%C/.SP&!DK*7D]("`@(>$]>V
M`1.65@`37@X"EI=9CO*7$Y?D`8F`LI=%CRZ7,P9O`,:6PIZ"%X&3`A:"%I.5
M#@("%X&2`9*!D0&3'.$4Y1#Q#.V#-H3\@[<#`+6/@488Z9'O@S"!*P,T`2N#
M-($J`SD!*H,Y@2D3`0$L@H#OT&^,01$BX`;D``@3!0`([\!_VQ=(```#."A)
MMW9=3#=WZ6&&!K<E16<W5C(0!@>3AN;/DX45,!,&9D<3!P<?%.DC-`4"(S@%
M`B,L!08,X2,T!0$0[1CQHF`"9$$!@H!=<:+@2OA.]%;L6NB&Y";\4O"`"!AU
MDQ<V`+*)NI<0>8(7@9,SM^<`*HF3UMD!*%TZEC.'Q@`C-/D"(SCI`BZ+DPJ)
M`S7MDP?P`V/:-P4;VFD`7N2;"_K_8N`:"A.<"P(37`P"6IK:A*:%$P8`!%:%
M[\!_X).$!`1*A>_@OYKCE43_NPMP09N;:P`:#)N)"?P3"PL$NXD[`6*;HFL"
M;-J%5H5.AN_`/]TC+#D'IF`&9.)T0GFB>0)ZXFI":V%A@H"3!P`$B9^^A&/+
M^0(;B@0`DPJ)`U*&5I7:A>_`W]F#)XD'$P<`!*6?(RSY!N.0Y_Q*A;N)F4!2
MF^_@WY*IM\Z$\;==<:+@)OQ*^%+P5NQ>Y(;D3O1:Z(`(@[F%`H/6A0(#UP4#
MD]<Y`).+A0.3]_<#$]J&`)-:AP";EH8`&Q>'`#.&^P"NA#-JV@"3!0#XL^KJ
M``.[!`.%)R,`M@!"&L(:$P:``RJ)$UH*`S.%^P"3V@H#8U;V$!,'``2[!_=`
M$4=C\.<2"4=C].<08Y\'#B:%[^!?B5Z%$P:``X%%[\"_XI/7B0$35XL!D]D)
M`1-;"P$CF50'(YM$!Z.(9`<CBO0&HXHT!R:%(XCD!N_@OX6<8":%X8,C`/D`
MG&#!@Z,`^0"<8*&#(P'Y`)Q@HP'Y`)QDX8,C`OD`G&3!@Z,"^0"<9*&#(P/Y
M`)QDHP/Y`)QHX8,C!/D`G&C!@Z,$^0"<:*&#(P7Y`)QHHP7Y`)QLX8,C!OD`
MG&S!@Z,&^0"<;*&#(P?Y`)QLHP?Y`)QPX8,C"/D`G'#!@Z,(^0"<<*&#(PGY
M`)QPHPGY``9DIF#B=$)YHGD">N)J0FNB:V%A;\#?R!V>@47OP%_4*;\C``4`
M";<C``4`HP`%`/D7.I7CB@?N[;<C``4`HP`%`",!!0"C`04`\1<ZE0E'X^KG
M[-&_01$BX`;D``@"9*)@EV8``(.VYNA!`6_`7[0!``(``````"5S+R5S````
M+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``
M````26YT97)N86QS.CI005(Z.D)/3U0`````97AE```````O<')O8R\E:2\E
M<P``````+@````````!005)?5$5-4```````````4$%27U!23T=.04U%````
M`#H`````````+P`````````E<R5S)7,``%!%4DPU3$E"``````````!015),
M3$E"`%!%4DPU3U!4``````````!015),24\``%!!4E])3DE424%,25I%1`!0
M05)?4U!!5TY%1```````4$%27T-,14%.`````````%!!4E]$14)51P``````
M``!005)?0T%#2$4`````````4$%27T=,3T)!3%]$14)51P``````````4$%2
M7T=,3T)!3%]435!$25(`````````4$%27U1-4$1)4@```````%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.```````````Q`````````&QS965K
M(&9A:6QE9`````!R96%D(&9A:6QE9```````3$1?3$E"4D%265]0051(`%-9
M4U1%30``+W1M<`````!54T52`````%5315).04U%```````````E,#)X````
M`'!A<BT`````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E
M<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@
M<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%4
M2`````!P87)L`````"YP87(`````<VAO<G0@<F5A9````````"5S)7-C86-H
M92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````
M````&`````````!P97)L`````#``````````4$%2.CI086-K97(Z.E9%4E-)
M3TX`````,2XP-C,```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````+64````````M
M+0```````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````979A;"`G
M97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@
M;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L
M.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N
M86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B([
M"B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?
M;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*
M?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU
M;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D
M9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?
M<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU
M;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P
M.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-
M04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI
M(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S
M:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L
M($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO
M=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD
M9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T
M96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>
M3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I4
M14U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]
M/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@
M)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR
M;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T
M:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M
M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL
M96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F
M(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P
M<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]
M"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9)
M;G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*
M;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T
M<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M
M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0
M?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI
M.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL
M97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;
M0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@
M=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)
M0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF
M("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@
M<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA
M<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N
M("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O
M9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@
M)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%
M(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K
M97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME
M<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E
M=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H
M(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S
M970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@
M)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@
M*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B
M=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*
M;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I
M(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]
M?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE
M9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U
M-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE
M;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U
M;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*
M8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*
M?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B
M=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U
M;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*
M;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE
M<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#
M>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R
M96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I
M;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H
M.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC
M<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE
M;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]
M"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE
M("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS
M;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F
M:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL
M96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE
M;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C
M=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL
M96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q
M6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R
M;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@
M7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@
M0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?
M;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE
M("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@
M:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@
M("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM
M<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@
M<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R
M"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q
M("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU
M;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD
M;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I
M=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]
M"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@
M97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N
M)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4
M)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY
M("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-
M4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L
M("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@
M9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B
M=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A
M('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E
M("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/
M7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE
M('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO
M9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D
M("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L
M("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@
M=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I
M"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A
M73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?
M;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@
M>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV
M;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I
M;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ
M9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]
M("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?
M97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H
M<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E
M9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI
M('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%
M+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T
M.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF
M("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*
M?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N
M>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O
M7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)
M3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL
M92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@
M/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P
M96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A
M9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB
M961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA
M;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*
M?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@
M*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T
M94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C
M;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E
M;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@
M87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I
M;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M
M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L
M<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I
M9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M
M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M
M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X
M("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H
M+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T
M(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*
M8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN
M960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL
M93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C
M:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P
M96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE
M9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P
M,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB
M*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M
M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U
M=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O
M<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM
M;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*
M?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\
M("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@
M+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L
M(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*
M?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@
M1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR
M97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@
M=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*
M<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y
M;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E
M<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT
M;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(
M86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL
M:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B
M)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE
M*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D
M14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE
M;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I
M8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H
M+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP
M0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B
M7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#
M04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L
M("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I
M<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H
M95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%
M04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I
M<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S
M=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E
M7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F
M:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D
M9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N
M86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL
M;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M
M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.
M5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I
M('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[
M7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O
M+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!]
M(&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES
M>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM
M?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I
M<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M
M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF
M("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G
M;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@
M*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E
M9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W
M9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D
M<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF
M("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI]
M(&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H
M(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@
M>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%
M35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!
M4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)]
M.PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%
M04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO
M9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`
M7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H
M($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL
M('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI
M8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@
M;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?
M<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#
M86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I
M;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P
M<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@
M:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T52
M4D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,``````````$-!0TA%``")J\WO
M``````$;`SOL````'````#B,__\<!P``Y(W__P0!``#6CO__&`$``(*/__^(
M`0``[H___\`!```8D?__+`(``.J2__^@`@``NI/__^0"```:E/__$`,``%"4
M__\X`P``"I7__WP#```:E?__I`,``,Z6___X`P``]I;__R0$``#HE___<`0`
M`(Z;__^L!```Z)O__]P$```\G/___`0``$*=__]$!0``7IW__VP%```PGO__
MU`4``%ZC__]\!@``(*7__\`&``#6I?__8`<``%:[__^<!P``LKO__\0'``"T
MO/__%`@``&Z^__]@"````````!```````````WI2``%\`0$;#`(`$````!@`
M``#8C/__(@`````'`0!L````+````+:-__^L`````$(.4$B(!($"B0:7$D(,
M"`!:DPJ4#)4.9I((EA!HTD+30M1"U4+60L%"R`P"4$+71,E"#@!"#0B!`H@$
MB0:2"),*E`R5#I80EQ)2TM9$T]351),*E`R5#D+30M1"U0``-````)P```#R
MC?__;`````!"#K`!1H@$B0:2"$(,"`!*@0("2@K!0L@,`K`!0LE"TD(.`$(+
M``!H````U````":.__\J`0```$(.T`%&B`23"H$"0@P(`%J)!D;)4L%"R`P"
MT`%"TT(.`$(-"($"B`2)!I,*0I((3)0,`D*5#@)<U50*R4+20M1""T:5#DC)
MTM352(D&D@B4#)4.1-350LE"T@!P````0`$``.2.___2`0```$(.<%*(!(D&
MD@B3"H$"E`R5#I<2F!1"#`@``MX*P4+(#`)P0LE"TD+30M1"U4+70MA"#@!"
M"W"6$)D6FA@"7@K60ME"VD8+5M;9VD26$)D6FAA&UMG:1I80F1::&$;60ME"
MVD````"T`0``0I#__]``````0@Y03(@$B0:2"),*E`R5#D(,"`!6@0("8@H,
M`E!"P4+(0LE"TD+30M1"U4(.`$(+````*````/@!``#.D/__8`````!"#B!"
MB09,B`2!`D(,"`!FR`P"($3!0LE>#@`D````)`(```*1__\V`````$H.$$2(
M!($"0@P(`$3(#`(00L%<#@``0````$P"```0D?__N@````!"#F!&@0*(!(D&
M0@P(`$J2"),*E`R5#@*."@P"8$+!1,A"R4+20M-"U$+50@X`0@L````D````
MD`(``(:1__\0`````$(.$$2(!($"0@P(`$+(#`(00L%"#@``4````+@"``!N
MD?__M`$```!"#O`!2H@$B0:2"),*EQ)"#`@`8($"E`R5#I80F!29%@)."@P"
M\`%"P4+(0LE"TD+30M1"U4+60M="V$+90@X`0@L`*`````P#``#.DO__*```
M``!"#B!&B`2)!H$"0@P(`%+(#`(@0L%$R4(.``!(````.`,``,J2___R````
M`$(.0$J(!),*@0*)!I((0@P(``*>"@P"0$+!0LA"R4+20M-"#@!""U(*#`)`
M0L%"R$+)0M)"TTH.`$0+.````(0#``!PD___I@,```!"#D!(B`2)!I((DPI"
M#`@`2H$"`TX#"L@,`D!"P4+)0M)"TU(.`$0+````+````,`#``#:EO__6@``
M``!"#C!$B`2)!D(,"`!*@0)X"L%"R`P",$+)0@X`0@L`'````/`#```$E___
M5`````!"#F!$B!2!$D(,"$````!$````$`0``#B7__\&`0```$(.8%*(!),*
ME`R5#H$"B0:2")80EQ)"#`@``K(*#`)@0L%"R$+)0M)"TT+40M5"UD+70@X`
M0@LD````6`0``/:7__\<`````$(.$$2!`H@$0@P(`$[!0L@,`A!"#@``9```
M`(`$``#JE___T@````!"#D!&B`22"),*0@P(`&*!`DR)!D;)6L@,`D!"P4+2
M0M-"#@!$#0B!`H@$B0:2"),*1)0,`D3(#`)`0M1"P4+20M-$R4H.`$0-"($"
MB`22"),*1(D&E`RD````Z`0``%28__\N!0```$(.H`-,B`22"$(,"`!DDPJ4
M#($"B08"AI4.EA"7$I@4`VP!"L%"R`P"H`-"UD+70MA"R4+20M-"U$350@X`
M0@L"?)D61MEBU=;7V%;(#`*@`T+!0M)"TT+41,E"#@!$#0B!`H@$B0:2"),*
ME`R5#I80EQ*8%)D6`RP!"ME""P/B`-E"F19$U=;7V-E*E0Z6$)<2F!29%@!`
M````D`4``-J<___"`0```$(.4$*)!E2(!),*E`R!`I((E0Y"#`@``U0!"L%"
MR`P"4$+)0M)"TT+40M5"#@!""P```%@```#4!0``6)[__[8`````0@Y`1H@$
MB0:2"$(,"`!@@0)L"L%"R`P"0$+)0M)"#@!""T23"FP*TT(+3L@,`D!"TT+!
M0LE$TD(.`$0-"($"B`2)!I((0I,*````0````#`&```4A?__J@$```!"#F!&
M@0*(!)((0@P(`$:)!I,*E`P#*@$*P4+(#`)@0LE"TD+41--"#@!""P``````
M```X````=`8``&Z>__^`%0```$0.P`5$B`1"#`@`7H$"B0:2"),*`SX5"L%$
MR`P"P`5$R4321--$#@!""P`D````L`8``+*S__]<`````$(.$$2(!($"0@P(
M``).P4+(#`(00@X`3````-@&``#FL___`@$```!"#E!0B`22"),*E0Z6$($"
MB0:4#$(,"``"0)<21I@4`D+70MA0"L%"R`P"4$+)0M)"TT+40M5"UD(.`$(+
M``!(````*`<``)BT__^Z`0```$(.4%*(!(D&D@B4#)4.EQ*!`I,*EA!"#`@`
M`U`!"L@,`E!"P4+)0M)"TT+40M5"UD+70@X`1`L`````)````'0'```&MO__
M&@````!"#A!$B`2!`D(,"`!"R`P"$$+!2@X`````````````````````````
M``````````````````````````````````````````$`````````^0(`````
M```!``````````D#`````````0`````````3`P```````"``````````F*L`
M```````A``````````@`````````&0````````"@JP```````!L`````````
M"``````````:`````````*BK````````'``````````(`````````/7^_V\`
M````R`,````````%`````````#`.````````!@````````"X!`````````H`
M````````O00````````+`````````!@`````````%0``````````````````
M``,`````````P*T````````"`````````%@%````````%``````````'````
M`````!<`````````*!8````````'`````````!@4````````"`````````!H
M!P````````D`````````&``````````>``````````@`````````^___;P``
M```!```(`````/[__V\`````N!,```````#___]O``````(`````````\/__
M;P````#N$@```````/G__V\`````"P``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````/__________``````````"`&P```````(`;
M````````@!L```````"`&P```````(`;````````@!L```````"`&P``````
M`(`;````````@!L```````"`&P```````(`;````````@!L```````"`&P``
M`````(`;````````@!L```````"`&P```````(`;````````@!L```````"`
M&P```````(`;````````@!L```````"`&P```````(`;````````@!L`````
M``"`&P```````(`;````````@!L```````"`&P```````(`;````````@!L`
M``````"`&P```````(`;````````@!L```````"`&P```````(`;````````
M@!L```````"`&P```````(`;````````@!L```````"`&P```````(`;````
M````@!L```````"`&P```````(`;````````@!L```````"`&P```````(`;
M````````@!L```````"`&P```````(`;````````@!L```````"`&P``````
M`(`;````````@!L```````"`&P```````(`;````````@!L```````"PJP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H56)U;G1U(#$T+C(N,"TT=6)U;G1U,BD@,30N,BXP`$%E````<FES
M8W8``5L````$$`5R=C8T:3)P,5]M,G`P7V$R<#%?9C)P,E]D,G`R7V,R<#!?
M>FEC<W(R<#!?>FEF96YC96DR<#!?>FUM=6PQ<#!?>F%A;6\Q<#!?>F%L<G-C
M,7`P```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO
M=&4N<&%C:V%G90`N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N
M<F5L82YP;'0`+G1E>'0`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M
M90`N<')E:6YI=%]A<G)A>0`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN
M86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+G)I<V-V+F%T=')I8G5T
M97,`````````````````````````````````````````````````````````
M``````````````````````````````L````!`````@````````!P`@``````
M`'`"````````(0````````````````````$````````````````````3````
M!P````(`````````E`(```````"4`@```````"0````````````````````$
M````````````````````)@````<````"`````````+@"````````N`(`````
M``#L````````````````````!````````````````````#0````'`````@``
M``````"D`P```````*0#````````(`````````````````````0`````````
M``````````!"````]O__;P(`````````R`,```````#(`P```````.P`````
M````!@`````````(````````````````````3`````L````"`````````+@$
M````````N`0```````!X"0````````<````"````"``````````8````````
M`%0````#`````@`````````P#@```````#`.````````O00`````````````
M``````$```````````````````!<````____;P(`````````[A(```````#N
M$@```````,H`````````!@`````````"``````````(`````````:0```/[_
M_V\"`````````+@3````````N!,```````!@``````````<````"````"```
M`````````````````'@````$`````@`````````8%````````!@4````````
M$`(````````&``````````@`````````&`````````""````!````$(`````
M````*!8````````H%@```````%@%````````!@```!4````(`````````!@`
M````````AP````$````&`````````(`;````````@!L```````"P`P``````
M````````````$``````````0`````````(P````!````!@`````````P'P``
M`````#`?````````4#(```````````````````0```````````````````"2
M`````0````(`````````@%$```````"`40```````'A!````````````````
M```(````````````````````F@````$````"`````````/B2````````^)(`
M``````#L````````````````````!````````````````````*@````!````
M`@````````#HDP```````.B3````````G`<```````````````````@`````
M``````````````"R````$`````,`````````F*L```````"8FP````````@`
M```````````````````!``````````@`````````P0````X````#````````
M`*"K````````H)L````````(````````````````````"``````````(````
M`````,T````/`````P````````"HJP```````*B;````````"```````````
M``````````@`````````"`````````#9````!@````,`````````L*L`````
M``"PFP```````!`"````````!P`````````(`````````!``````````X@``
M``$````#`````````,"M````````P)T```````!``@``````````````````
M"``````````(`````````.<````!`````P``````````L`````````"@````
M````4`````````````````````@```````````````````#M````"`````,`
M````````4+````````!0H````````"@````````````````````(````````
M````````````\@````$````P````````````````````4*`````````E````
M`````````````````0`````````!`````````/L````#``!P````````````
M`````````'6@````````9@````````````````````$`````````````````
M```!`````P````````````````````````#;H`````````T!````````````
5```````!````````````````````
